currency-rate
=============

Python library for easy convert currencies

Features:
--------
- List of currency rates relatively base currency
- List of currencies
- Get history currency rate
- Convert one currency to another with specific amount
- Currency symbols
- Currency description

Installation
--------------

- Install using python package

	.. code-block:: python

			pip install currency-rate

				Or directly cloning the repo:

			python setup.py install

